<div class="issues_con fl">
  <div class="clear mb5">
    <a href="<%= new_project_issue_path(@project)%>" class="sy_btn_green  fl mr10">新 增</a>
    <div class="issues_statistics fl">
      <ul>
        <li>所有<a href="javascript:void(0);" class="issues_greycirbg_btn "><%= @project.project_score.issue_num %></a></li>
        <li>开启<a href="javascript:void(0);" class="issues_greycirbg_btn "><%= @project.issues.where('status_id in (1,2,3,4,6)').visible.all.count  %></a></li>
        <li>关闭<a href="javascript:void(0);" class="issues_greycirbg_btn "><%= @project.issues.where(:status_id => 5 ).visible.all.count  %></a></li>
      </ul>
    </div><!--issues_statistics end-->
    <a href="<%=project_issues_path(:project_id => @project, :format => 'xls')%>" class="hw_btn_blue  fr" alt="导出EXCEL">导出EXCEL</a>
  </div>
  <% unless @project.enabled_modules.where("name = 'issue_tracking'").empty? %>
      <%= form_tag({:controller => 'issues', :action => 'index', :project_id => @project},:remote=>'true', :method => :get,:id=>"issue_query_form", :class => 'query_form') do %>
          <%= hidden_field_tag 'set_filter', '1' %>
          <div class="clear mb10">
            <div class="hw_search_box fl ">
              <input class="hw_search-input" placeholder="请输入问题名称" type="text" id="v_subject"  name="subject" onkeypress="EnterPress(event)" onkeydown="EnterPress()">
              <a href="javascript:void(0);" class="hw_btn_search" onclick="remote_function();" ></a>
            </div>
            <a href="javascript:void(0);" class="sy_btn_grey fl ml5" onclick="nh_reset_form();">清除</a>
            <div class="calendar_div fr">
              <input name="issue_create_date_end" nhname="date_val" type="hidden"/>
              <input type="text" nhname="date_show" id="issue_create_date_end_show" class="InputBox fl W120 calendar_input" readonly="readonly" size="13" placeholder="结束日期">
              <%= calendar_for('issue_create_date_end_show')%>
            </div>
              <div class="calendar_div fr">
                <input name="issue_create_date_start_show" nhname="date_val" type="hidden"/>
                <input type="text" nhname="date_show" id="issue_create_date_start_show" class="InputBox fl W120 calendar_input" readonly="readonly" size="13" placeholder="开始日期">
                    <%= calendar_for('issue_create_date_start_show')%>
              </div>

              <!--<input type="text"  placeholder="开始日期" class="issues_calendar_input fl " ><a href="" class="issues_data_img fl" style="border-right:none;"></a>-->
              <!--<input type="text"  placeholder="结束日期" class="issues_calendar_input fl " ><a href="" class="issues_data_img fl"></a>-->

          </div>

        <div class="issues_con_list" style="position: relative;">
          <ul id="issues_list_nav" >
            <li id="issues_list_nav_1" class="issues_nav_hover" onclick="HoverLi(1);">
              <a href="javascript:void(0);" onclick="all_reset_form();" id="issues_type_1" >所有<span class="issues_nav_tag ml5"><%= @project.project_score.issue_num %></span></a>
            </li>
            <li id="issues_list_nav_2" onclick="HoverLi(2);">
              <a href="javascript:void(0);" onclick="switch_assign_to(<%= User.current.id %>)" id="issues_type_2" >指派给我<span class="issues_nav_tag ml5"><%= @project.issues.where(:assigned_to_id => User.current.id ).visible.all.count  %></span></a>
            </li>
            <li id="issues_list_nav_3" onclick="HoverLi(3);">
              <a href="javascript:void(0);" onclick="createByMe(<%= User.current.id %>)" id="issues_type_3" >我的发布<span class="issues_nav_tag ml5"><%= @project.issues.where(:author_id => User.current.id ).visible.all.count  %></span></a>
            </li>
            <div class="cl"></div>
          </ul>
          <div class="issues_filter ">
            <div class="issues_form_filter mt5 mr5">
              <%= select(:issue, :tracker_id, [["缺陷",1],["功能",2],["支持",3],["任务",4],["周报",5]].unshift(["类型",0]),
                      {:include_blank => false, :selected => @tracker_id ? @tracker_id : 0},
                      {:onchange => "remote_function();", :id => "tracker_id", :name => "tracker_id", :class => "fl issues_filter_select_min"}) %>
              <%= select( :issue, :user_id, principals_options_for_isuue_list(@project),
                          { :include_blank => false,:selected=>@assign_to_id ? @assign_to_id : 0},
                          {:onchange=>"remote_function();",:id=>"assigned_to_id",:name=>"assigned_to_id",:class=>"fl"})
              %>

              <%= select(:issue, :fixed_version_id, options_for_version_isuue_list(@project),
                      {:include_blank => false, :selected => @fixed_version_id ? @fixed_version_id : 0},
                      {:onchange => "remote_function();", :id => "fixed_version_id", :name => "fixed_version_id", :class => "f1"}) %>

              <%= select( :issue,:status, [["新增",1],["正在解决",2],["已解决",3],["反馈",4],["关闭",5],["拒绝",6]].unshift(["状态",0]),
                          { :include_blank => false,:selected=>@status_id ? @status_id : 0
                          },
                          {:onchange=>"remote_function();",:id=>"status_id",:name=>"status_id",:class=>"fl issues_filter_select_min"}
                  ) %>

              <%= select(:issue, :done_ratio, [["10%",1],["20%",2],["30%",3],["40%",4],["50%",5],["60%",6],["70%",7],["80%",8],["90%",9],["10%",10]].unshift(["完成度",0]),
                         {:include_blank => false, :selected => @done_ratio ? @done_ratio : 0 },
                         {:onchange => "remote_function();", :id => "done_ratio", :name => "done_ratio", :class => "f1"}) %>

              <%= select(:issue, :test, [["最早创建",1],["最早更新",2]].unshift(["排序",0]),
                      {:include_blank => false, :selected => @order ? @order : 0 },
                      {:onchange => "remote_function();", :id => "test", :name => "test", :class => "fr issues_filter_select_min"}) %>
            </div>
            <div class="cl"></div>
          </div><!--issues_filter end-->
          <% if @issues.empty? %>
              <p class="nodata"><%= l(:label_no_data) %></p>
          <% else %>
              <div id="issue_list">
                <%= render :partial => 'issues/all_list', :locals => {:issues => @issues, :query => @query,:issue_pages=>@issue_pages,:issue_count=>@issue_count,:project=>@project,:subject=>@subject} %>
              </div>
          <% end %>
          <%#= render :partial => 'issues/all_list', :locals => {:issues => @issues, :query => @query,:issue_pages=>@issue_pages,:issue_count=>@issue_count,:project=>@project,:subject=>@subject} %>
        </div><!--issues_con_list end-->

      <% end %>
  <% end %>
</div>
